<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns="http://www.w3.org/1999/xhtml"
	xmlns:xhtml="http://www.w3.org/1999/xhtml"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ws="http://www.ebenoit.info/data"
	xmlns:wsf="http://www.ebenoit.info/ext">


	<!-- *********************************************************************************************** -->
	<!-- * HTML CONTENTS AND ENGINE TAGS                                                               * -->
	<!-- *********************************************************************************************** -->


	<!-- HTML content copy
	   -
	   - This template copies the HTML contents while making sure ws:* templates are applied as well.
	  -->
	<xsl:template match="@*|node()" priority="-5">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()"/>
		</xsl:copy>
	</xsl:template>

	<!-- Handle hX tags through generate-h-identifier, in case we need it -->
	<xsl:template match="xhtml:h1|xhtml:h2|xhtml:h3|xhtml:h4|xhtml:h5|xhtml:h6">
		<xsl:variable name="id" select="wsf:generate-h-identifier( name() , string( @id ) )" />

		<xsl:copy>
			<xsl:if test="$id != ''">
				<xsl:attribute name="id">
					<xsl:value-of select="$id" />
				</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select="@*[ name() != 'id' ]|node()"/>
		</xsl:copy>
	</xsl:template>


	<!-- Link tag handler
	   -
	   - This template handles the <ws:link-to> tag which generates links, either to pages handled by
	   - the engine or to content hosted on the site.
	  -->
	<xsl:template match="ws:link-to">
		<a>
			<!-- Generate the link's target URL -->
			<xsl:attribute name="href">
				<xsl:choose>

					<!-- Link to a page handled by the engine -->
					<xsl:when test="@page">
						<xsl:choose>
							<xsl:when test="@anchor">
								<xsl:value-of select="concat( $scriptPath , '/' , $lang , '/' , @page , '#' , @anchor )" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="concat( $scriptPath , '/' , $lang , '/' , @page)" />
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>

					<!-- Link relative to the site's root -->
					<xsl:when test="@relative">
						<xsl:value-of select="concat( $webRoot , @relative )" />
					</xsl:when>

					<!-- Invalid link :'( -->
					<xsl:otherwise>/invalid-link</xsl:otherwise>

				</xsl:choose>
			</xsl:attribute>

			<!-- Generate the link's title, either from the title attribute or from the page's
			   - title (provided this is a page link). If no title is found, a default is used
			   - to prevent the site from becoming invalid XHTML.
			  -->
			<xsl:attribute name="title">
				<xsl:choose>

					<!-- Is there a title string? -->
					<xsl:when test="@title">
						<xsl:value-of select="@title" />
					</xsl:when>

					<!-- If it is a page, use its title -->
					<xsl:when test="@page">
						<xsl:value-of select="wsf:get-page-title( string( @page ) , string( $lang ) , true() )" />
					</xsl:when>

					<!-- Nothing... use the default. -->
					<xsl:otherwise>
						<xsl:call-template name="get-i18n-string">
							<xsl:with-param name="id">untitled-link</xsl:with-param>
						</xsl:call-template>
					</xsl:otherwise>

				</xsl:choose>
			</xsl:attribute>

			<!-- Generate the class attribute -->
			<xsl:variable name="link-class">
				<xsl:value-of select="wsf:make-link-class( string( $lang ) , string( @page ) , string( @anchor ) , string( @class ) )" />
			</xsl:variable>
			<xsl:if test="$link-class != ''">
				<xsl:attribute name="class">
						<xsl:value-of select="$link-class" />
				</xsl:attribute>
			</xsl:if>

			<!-- Copy the style and id attributes, as well as the tag's contents -->
			<xsl:apply-templates select="@style|@id" />
			<xsl:apply-templates select="node()" />
		</a>
	</xsl:template>


	<!-- Image tag handler
	   -
	   - This template handles the <ws:image> tag which generates images.
	  -->
	<xsl:template match="ws:image">
		<img>
			<!-- Source URL -->
			<xsl:attribute name="src">
				<xsl:choose>

					<!-- External image -->
					<xsl:when test="@external">
						<xsl:value-of select="@external" />
					</xsl:when>

					<!-- Image on the site itself -->
					<xsl:when test="@relative">
						<xsl:call-template name="image-source">
							<xsl:with-param name="file" select="@relative" />
						</xsl:call-template>
					</xsl:when>

					<!-- Invalid image -->
					<xsl:otherwise>
						<xsl:call-template name="image-source">
							<xsl:with-param name="file" select="'error.png'" />
						</xsl:call-template>
					</xsl:otherwise>

				</xsl:choose>
			</xsl:attribute>

			<!-- Image title -->
			<xsl:attribute name="alt">
				<xsl:choose>
					<xsl:when test="@title">
						<xsl:value-of select="@title" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="get-i18n-string">
							<xsl:with-param name="id">untitled-image</xsl:with-param>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>

			<!-- Copy the style, class and id attributes -->
			<xsl:apply-templates select="@style|@class|@id" />
		</img>
	</xsl:template>


	<!-- We need to ignore metadata and inclusion tags that may be in the page's
	   - source.
	  -->
	<xsl:template match="ws:author" />
	<xsl:template match="ws:css" />
	<xsl:template match="ws:script" />
	<xsl:template match="ws:keyword" />
	<xsl:template match="ws:meta" />

</xsl:stylesheet>
