<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns="http://www.w3.org/1999/xhtml"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ws="http://www.ebenoit.info/data"
	xmlns:wsf="http://www.ebenoit.info/ext">


	<!-- *********************************************************************************************** -->
	<!-- * HTML HEAD TAG CONTENTS                                                                      * -->
	<!-- *********************************************************************************************** -->


	<!-- HTML header
	   -
	   - This template generates the <head> section of the HTML page.
	  -->
	<xsl:template name="html-header">
		<!-- Site + page title -->
		<title>
			<xsl:call-template name="page-title-template">
				<xsl:with-param name="site-title" select="wsf:get-site-title( string( $lang ) )" />
				<xsl:with-param name="page-title">
					<xsl:value-of select="wsf:get-page-title( string( $page ) , string( $lang ) , true() )" />
				</xsl:with-param>
			</xsl:call-template>
		</title>

		<!-- Content type -->
		<meta http-equiv="Content-Type" content="application/xhtml+xml;charset=utf-8" />

		<!-- Author -->
		<xsl:if test="wsf:get-page-author( string( $page ) , string( $lang ) ) != ''">
			<meta name="author">
				<xsl:attribute name="content">
					<xsl:value-of select="wsf:get-page-author( string( $page ) , string( $lang ) )" />
				</xsl:attribute>
			</meta>
		</xsl:if>

		<!-- Keywords -->
		<xsl:if test="wsf:get-meta-data( string( $lang ) , string( $page ) , 'keyword' )">
			<xsl:variable name="kw" select="wsf:get-meta-data( string( $lang ) , string( $page ) , 'keyword' )" />
			<meta name="keywords">
				<xsl:attribute name="content">
					<xsl:value-of select="$kw/ws:keyword[ 1 ]" />
					<xsl:for-each select="$kw/ws:keyword[ position() > 1 ]">
						<xsl:value-of select="concat( ',' , text() )" />
					</xsl:for-each>
				</xsl:attribute>
			</meta>
		</xsl:if>

		<!-- Generate other meta tags -->
		<xsl:call-template name="other-meta-tags" />

		<!-- Load stylesheets and scripts -->
		<xsl:call-template name="load-all-css" />
		<xsl:call-template name="load-all-scripts" />
	</xsl:template>


	<!-- HTML meta tags generator
	   -
	   - This template generates the page's various meta tags from the configuration;
	   - it uses language- and page-specific values if they exist, then language-independant
	   - but page-specific values and finally site-wise values.
	  -->
	<xsl:template name="other-meta-tags">
		<!-- Site-wise meta tags -->
		<xsl:for-each select="wsf:get-meta-data( string( $lang ) , string( $page ) , 'meta' , 'name' )/ws:meta">
			<meta>
				<xsl:attribute name="name"><xsl:value-of select="@name" /></xsl:attribute>
				<xsl:attribute name="content"><xsl:value-of select="text()" /></xsl:attribute>
			</meta>
		</xsl:for-each>
	</xsl:template>


	<!-- Load user stylesheets
	   -
	   - This template loads both site-wise stylesheets and page-specific stylesheets.
	  -->
	<xsl:template name="load-all-css">
		<xsl:for-each select="wsf:get-meta-data( string( $lang ) , string( $page ) , 'css' )/ws:css">
			<xsl:call-template name="include-css"><xsl:with-param name="file" select="text()" /></xsl:call-template>
		</xsl:for-each>
	</xsl:template>


	<!-- JavaScript loader
	   -
	   - This template loads all required JavaScript files.
	  -->
	<xsl:template name="load-all-scripts">
		<xsl:for-each select="wsf:get-meta-data( string( $lang ) , string( $page ) , 'script' )/ws:script">
			<xsl:call-template name="include-javascript"><xsl:with-param name="file" select="text()"/></xsl:call-template>
		</xsl:for-each>
	</xsl:template>


	<!-- Image pre-loader
	   -
	   - This template generates the code for the image pre-loader hidden div.
	  -->
	<xsl:template name="image-preloader">
		<xsl:if test="wsf:get-meta-data( string( $lang ) , string( $page ) , 'image-preload' , 'id' )/ws:image-preload">
			<div style="display:none">
				<xsl:for-each select="wsf:get-meta-data( string( $lang ) , string( $page ) , 'image-preload' , 'id' )/ws:image-preload">
					<img id="{@id}" alt="(preload)">
						<xsl:attribute name="src">
							<xsl:call-template name="image-source">
								<xsl:with-param name="file" select="text()" />
							</xsl:call-template>
						</xsl:attribute>
					</img>
				</xsl:for-each>
			</div>
		</xsl:if>
	</xsl:template>


</xsl:stylesheet>
